Class: RuntimeContext

Inherits:
AbstractRuntimeContext show all
Defined in:
lib/hypertube-ruby-sdk/sdk/runtime_context.rb

Overview

Represents a single context which allows interaction with a selected technology. Refers to a single instance of the called runtime within a particular target OS process. This can be either the local currently running process (inMemory) or a particular remote process identified by the IP Address and PORT of the target RuntimeBridge instance. Multiple Runtime Contexts can be initialized within one process. Calling the same technology on inMemory communication channel will return the existing instance of runtime context. Calling the same technology on TCP channel but on different nodes will result in unique Runtime Contexts. Within the runtime context, any number of libraries can be loaded and any objects from the target technology can be interacted with, as they are aware of each other due to sharing the same memory space and same runtime instance.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/foundations/runtime-context article on Hypertube Guides}

Constant Summary collapse

@@memory_runtime_contexts =
{}
@@network_runtime_contexts =
{}
@@ws_runtime_contexts =
{}
@@http2_runtime_contexts =
{}

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(runtime_name, connection_type, connection_data) ⇒ RuntimeContext

accessor set method



32
33
34
35
36
37
38
39
40
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 32

def initialize(runtime_name, connection_type, connection_data)
  @runtime_name = runtime_name
  @connection_type = connection_type
  @connection_data = connection_data
  @current_command = nil
  @is_stateless = false
  SdkMessageHelper.send_message_to_app_insights('SdkMessage',
                                                RuntimeNameHandler.get_name(@runtime_name).capitalize + ' initialized')
end

Instance Attribute Details

#connection_dataObject (readonly)

Returns the value of attribute connection_data.



28
29
30
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 28

def connection_data
  @connection_data
end

#current_commandObject

accessor get method



27
28
29
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 27

def current_command
  @current_command
end

#is_statelessObject

accessor get method



27
28
29
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 27

def is_stateless
  @is_stateless
end

#runtime_nameObject (readonly)

Returns the value of attribute runtime_name.



28
29
30
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 28

def runtime_name
  @runtime_name
end

Class Method Details

.build_connection_cache_key(runtime_name, connection_data) ⇒ Object



86
87
88
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 86

def self.build_connection_cache_key(runtime_name, connection_data)
  runtime_name.to_s + '|' + connection_data.to_canonical_key
end

.get_instance(runtime_name, connection_type, connection_data) ⇒ Object



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 42

def self.get_instance(runtime_name, connection_type, connection_data)
  rtm_ctx = case connection_type
            when ConnectionType::IN_MEMORY
              if @@memory_runtime_contexts.has_key?(runtime_name)
                @@memory_runtime_contexts[runtime_name]
              else
                runtime_ctx = RuntimeContext.new(runtime_name, connection_type, connection_data)
                @@memory_runtime_contexts[runtime_name] = runtime_ctx
                runtime_ctx
              end
            when ConnectionType::TCP
              key = build_connection_cache_key(runtime_name, connection_data)
              if @@network_runtime_contexts.has_key?(key)
                @@network_runtime_contexts[key]
              else
                runtime_ctx = RuntimeContext.new(runtime_name, connection_type, connection_data)
                @@network_runtime_contexts[key] = runtime_ctx
                runtime_ctx
              end
            when ConnectionType::WEB_SOCKET
              key = build_connection_cache_key(runtime_name, connection_data)
              if @@ws_runtime_contexts.has_key?(key)
                @@ws_runtime_contexts[key]
              else
                runtime_ctx = RuntimeContext.new(runtime_name, connection_type, connection_data)
                @@ws_runtime_contexts[key] = runtime_ctx
                runtime_ctx
              end
            when ConnectionType::HTTP2
              key = build_connection_cache_key(runtime_name, connection_data)
              if @@http2_runtime_contexts.has_key?(key)
                @@http2_runtime_contexts[key]
              else
                runtime_ctx = RuntimeContext.new(runtime_name, connection_type, connection_data)
                @@http2_runtime_contexts[key] = runtime_ctx
                runtime_ctx
              end
            else
              raise ArgumentError, 'Unknown connection type.'
            end
  rtm_ctx.current_command = nil
  rtm_ctx
end

.initialize_runtime_context(config) ⇒ RuntimeContext

Initializes RuntimeContext based on the Config object and loads modules.

Parameters:

  • config (Config)

    Instance of Config.

Returns:



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 93

def self.initialize_runtime_context(config)
  raise 'Config cannot be null.' if config.nil?

  connection_data = config.connection_data
  runtime = config.runtime

  connection_type = if connection_data.nil?
                      ConnectionType::IN_MEMORY
                    elsif connection_data.is_a?(TcpConnectionData)
                      ConnectionType::TCP
                    elsif connection_data.is_a?(WsConnectionData)
                      ConnectionType::WEB_SOCKET
                    elsif connection_data.is_a?(Http2ConnectionData)
                      ConnectionType::HTTP2
                    else
                      raise ArgumentError, 'Unknown connection type.'
                    end

  rtm_ctx = get_instance(runtime, connection_type, connection_data)

  rtm_ctx.is_stateless = config.is_stateless

  if connection_data.nil?
    modules = config.modules
    if modules && !modules.strip.empty?
      modules.split(',').each do |module_path|
        trimmed = module_path.strip
        next if trimmed.empty?

        begin
          full_path = File.realpath(File.expand_path(trimmed))
          rtm_ctx.load_library(full_path)
        rescue StandardError
          raise "Error resolving path for module: #{trimmed}"
        end
      end
    end
  end

  rtm_ctx
end

Instance Method Details

#as_out(*args) ⇒ InvocationContext

Creates a reference type argument that can be passed to a method with an out parameter modifier. This method is used when working with methods from the called runtime that require arguments to be passed by reference. The arguments include the value and optionally the type of the reference. The type must be retrieved from the called runtime using the getType method. After creating the reference, it can be used as an argument when invoking methods.

Parameters:

  • args (Array)

    The value and optionally the type of the reference.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/methods-arguments/passing-arguments-by-reference-with-out-keyword article on Hypertube Guides}


222
223
224
225
226
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 222

def as_out(*args)
  local_command = Command.new(@runtime_name, CommandType::AS_OUT, [*args])
  @current_command = nil
  build_invocation_context(local_command)
end

#as_ref(*args) ⇒ InvocationContext

Creates a reference type argument that can be passed to a method with a ref parameter modifier. This method is used when working with methods from the called runtime that require arguments to be passed by reference. The arguments include the value and optionally the type of the reference. The type must be retrieved from the called runtime using the getType method. After creating the reference, it can be used as an argument when invoking methods.

Parameters:

  • args (Array)

    The value and optionally the type of the reference.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/methods-arguments/passing-arguments-by-reference-with-ref-keyword article on Hypertube Guides}


208
209
210
211
212
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 208

def as_ref(*args)
  local_command = Command.new(@runtime_name, CommandType::AS_REF, [*args])
  @current_command = nil
  build_invocation_context(local_command)
end

#build_command(command) ⇒ Object



258
259
260
261
262
263
264
265
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 258

def build_command(command)
  return @current_command if command.nil? || command.payload.nil?

  command.payload.each_index do |i|
    command.payload[i] = encapsulate_payload_item(command.payload[i])
  end
  command.prepend_arg_to_payload(@current_command)
end

#build_invocation_context(command) ⇒ Object



253
254
255
256
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 253

def build_invocation_context(command)
  InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(command), false,
                        @is_stateless)
end

#cast(*args) ⇒ InvocationContext

Casts the provided value to a specific type. This method is used when invoking methods that require specific types of arguments. The arguments include the target type and the value to be cast. The target type must be retrieved from the called runtime using the getType method. After casting the value, it can be used as an argument when invoking methods. #see Refer to this article on Hypertube Guides

Parameters:

  • args (Array)

    The target type and the value to be cast.

Returns:



181
182
183
184
185
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 181

def cast(*args)
  local_command = Command.new(@runtime_name, CommandType::CAST, [*args])
  @current_command = nil
  build_invocation_context(local_command)
end

#encapsulate_payload_item(payload_item) ⇒ Object



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 267

def encapsulate_payload_item(payload_item)
  if payload_item.is_a? Command
    if payload_item.command_type == CommandType::VALUE || payload_item.command_type == CommandType::ARRAY
      return payload_item
    end

    payload_item.payload.each_index do |i|
      payload_item.payload[i] = encapsulate_payload_item(payload_item.payload[i])
    end
    payload_item

  elsif payload_item.is_a? InvocationContext
    payload_item.current_command

  elsif payload_item.is_a? Array
    copied_array = payload_item.map { |item| encapsulate_payload_item(item) }
    Command.new(@runtime_name, CommandType::ARRAY, copied_array)
  elsif TypesHandler.primitive_or_none?(payload_item)
    Command.new(@runtime_name, CommandType::VALUE, payload_item.nil? ? [nil] : [*payload_item])
  else
    raise TypeError, "Unsupported payload item type: #{payload_item.class} for payload item: #{payload_item}."
  end
end

#executeObject

Executes the current command. The initial state of RuntimeContext is non-materialized, wrapping either a single command or a chain of recursively nested commands. Commands become nested through each invocation of methods on RuntimeContext. Each invocation triggers the creation of a new RuntimeContext instance wrapping the current command with a new parent command. The developer can decide at any moment of the materialization for the context, taking full control of the chunks of the expression being transferred and processed on the target runtime.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/foundations/execute-method article on Hypertube Guides}


141
142
143
144
145
146
147
148
149
150
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 141

def execute
  @response_command = Interpreter.execute(@current_command, @connection_type, @connection_data)
  @current_command = nil

  return unless @response_command.command_type == CommandType::EXCEPTION

  exception = ExceptionThrower.throw_exception(@response_command)
  SdkMessageHelper.send_message_to_app_insights('SdkException', exception.message)
  raise exception
end

#get_enum_item(*args) ⇒ InvocationContext

Retrieves a specific item from an enum type. This method is used when working with enums from the called runtime. The arguments include the enum type and the name of the item. The enum type must be retrieved from the called runtime using the getType method. After retrieving the item, it can be used as an argument when invoking methods.

Parameters:

  • args (Array)

    The enum type and the name of the item.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/enums/using-enum-type article on Hypertube Guides}


194
195
196
197
198
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 194

def get_enum_item(*args)
  local_command = Command.new(@runtime_name, CommandType::GET_ENUM_ITEM, [*args])
  @current_command = nil
  build_invocation_context(local_command)
end

#get_global_field(field_name) ⇒ InvocationContext

Retrieves the value of a global field from the called runtime. The argument includes the global field name. After retrieving the field, the result can be used for further operations.

Parameters:

  • field_name (String)

    The name of the global field to retrieve.

Returns:

  • (InvocationContext)

    The InvocationContext instance that wraps the command to get the global field.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/fields-and-properties/getting-values-for-global-fields article on Hypertube Guides}


247
248
249
250
251
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 247

def get_global_field(field_name)
  local_command = Command.new(@runtime_name, CommandType::GET_GLOBAL_FIELD, [field_name])
  @current_command = nil
  build_invocation_context(local_command)
end

#get_type(*args) ⇒ InvocationContext

Retrieves a reference to a specific type. The type can be a class, interface or enum. The type can be retrieved from any referenced library.

Parameters:

  • args (Array)

    The full name of the type.

Returns:



169
170
171
172
173
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 169

def get_type(*args)
  local_command = Command.new(@runtime_name, CommandType::GET_TYPE, [*args])
  @current_command = nil
  build_invocation_context(local_command)
end

#invoke_global_function(function_name, *args) ⇒ InvocationContext

Invokes a function from the called runtime. This method is used when working with functions from the called runtime. The arguments include the function name and the arguments to be passed to the function. After invoking the function, the result can be used for further operations.

Parameters:

  • function_name (String)

    The name of the function to invoke.

  • args (Array)

    The arguments to be passed to the function.

Returns:

  • (InvocationContext)

    The InvocationContext instance that wraps the command to invoke the function.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/functions/invoking-functions article on Hypertube Guides}


235
236
237
238
239
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 235

def invoke_global_function(function_name, *args)
  local_command = Command.new(@runtime_name, CommandType::INVOKE_GLOBAL_FUNCTION, [function_name, *args])
  @current_command = nil
  build_invocation_context(local_command)
end

#load_library(*args) ⇒ RuntimeContext

Adds a reference to a library. RuntimeBridge allows you to reference and use modules or packages written in various languages. This method allows you to use any library from all supported technologies. The necessary libraries need to be referenced. The argument is a relative or full path to the library. If the library has dependencies on other libraries, the latter needs to be added first. After referencing the library, any objects stored in this package can be used. Use static classes, create instances, call methods, use fields and properties, and much more.

Parameters:

  • args (Array)

    The relative or full path to the library.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/getting-started/adding-references-to-libraries article on Hypertube Guides}


159
160
161
162
163
164
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 159

def load_library(*args)
  local_command = Command.new(@runtime_name, CommandType::LOAD_LIBRARY, [*args])
  @current_command = build_command(local_command)
  execute
  self
end