Class: Hypertube::Sdk::InvocationContext

Inherits:
Hypertube::Sdk::Internal::AbstractInvocationContext show all
Includes:
Enumerable
Defined in:
lib/hypertube-ruby-sdk/sdk/invocation_context.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Hypertube::Sdk::Internal::AbstractInvocationContext

#get_enum_item

Constructor Details

#initialize(runtime_name, connection_type, connection_data, command, is_executed = false, is_stateless = false) ⇒ InvocationContext

Returns a new instance of InvocationContext.



21
22
23
24
25
26
27
28
29
30
31
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 21

def initialize(runtime_name, connection_type, connection_data, command, is_executed = false, is_stateless = false)
  @is_executed = is_executed
  @is_stateless = is_stateless
  @runtime_name = runtime_name
  @connection_type = connection_type
  @connection_data = connection_data
  @current_command = command
  @response_command = nil
  # generates error: ruby/lib/Hypertube::Sdk::RuntimeBridge.rb-ruby-sdk/sdk/internal/invocation_context.rb:17: warning: finalizer references object to be finalized
  # ObjectSpace.define_finalizer(self, self.finalize(@current_command, @is_executed, @interpreter, @connection_type, @connection_data))
end

Instance Attribute Details

#connection_dataObject

Returns the value of attribute connection_data.



19
20
21
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 19

def connection_data
  @connection_data
end

#current_commandObject (readonly)

Returns the value of attribute current_command.



18
19
20
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 18

def current_command
  @current_command
end

#response_commandObject (readonly)

Returns the value of attribute response_command.



18
19
20
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 18

def response_command
  @response_command
end

Instance Method Details

#[](*indexes) ⇒ Object



51
52
53
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 51

def [](*indexes)
  get_index(*indexes).execute
end

#[]=(*indexes_and_value) ⇒ Object



55
56
57
58
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 55

def []=(*indexes_and_value)
  value = indexes_and_value.pop
  set_index(indexes_and_value, value).execute
end

#build_command(command) ⇒ Object



389
390
391
392
393
394
395
396
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 389

def build_command(command)
  return @current_command if command.nil? || command.payload.nil?

  command.payload.each_index do |i|
    command.payload[i] = encapsulate_payload_item(command.payload[i])
  end
  command.prepend_arg_to_payload(@current_command)
end

#build_invocation_context(local_command) ⇒ Object



384
385
386
387
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 384

def build_invocation_context(local_command)
  Hypertube::Sdk::InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(local_command), @is_executed,
                        @is_stateless)
end

#create_instance(*args) ⇒ Hypertube::Sdk::InvocationContext

Creates a new instance of a class in the target runtime. Invokes a constructor on the target runtime and registers the returned context for updates.

Parameters:

  • args (Array)

    The arguments to class constructor

Returns:

See Also:



149
150
151
152
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 149

def create_instance(*args)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::CREATE_CLASS_INSTANCE, [*args])
  build_invocation_context(local_command)
end

#create_nullHypertube::Sdk::InvocationContext

Creates a null object of a specific type in the target runtime.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/null-handling/create-null-object article on Hypertube Guides}


300
301
302
303
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 300

def create_null
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::CREATE_NULL, [])
  build_invocation_context(local_command)
end

#encapsulate_payload_item(payload_item) ⇒ Object



398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 398

def encapsulate_payload_item(payload_item)
  if payload_item.is_a? Hypertube::Utils::Command
    if payload_item.command_type == Hypertube::Utils::CommandType::VALUE || payload_item.command_type == Hypertube::Utils::CommandType::ARRAY
      return payload_item
    end

    payload_item.payload.each_index do |i|
      payload_item.payload[i] = encapsulate_payload_item(payload_item.payload[i])
    end
    payload_item

  elsif payload_item.is_a? Hypertube::Sdk::InvocationContext
    payload_item.current_command

  elsif payload_item.is_a? Array
    copied_array = payload_item.map { |item| encapsulate_payload_item(item) }
    Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::ARRAY, copied_array)
  elsif Hypertube::Utils::TypesHandler.primitive_or_none?(payload_item)
    Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::VALUE, payload_item.nil? ? [nil] : [*payload_item])
  else
    raise TypeError, "Unsupported payload item type: #{payload_item.class} for payload item: #{payload_item}."
  end
end

#execute(connection_data = nil) ⇒ Hypertube::Sdk::InvocationContext

Executes the current command. Because invocation context is building the intent of executing a particular expression on the target environment, we call the initial state of invocation context as non-materialized. The non-materialized context wraps either a single command or chain of recursively nested commands. Commands are becoming nested through each invocation of methods on Invocation Context. Each invocation triggers the creation of a new Invocation Context instance wrapping the current command with new parent command valid for invoked method. Developer can decide on any moment of the materialization for the context, taking full control of the chunks of the expression being transferred and processed on target runtime.

Parameters:

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/foundations/execute-method article on Hypertube Guides}


69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 69

def execute(connection_data = nil)
  @connection_data = connection_data unless connection_data.nil?

  raise 'currentCommand is undefined in Hypertube::Sdk::InvocationContext execute method' if @current_command.nil?

  return self if @is_stateless && @current_command.command_type != Hypertube::Utils::CommandType::PASS_BY_VALUE

  @response_command = Hypertube::Core::Interpreter::Interpreter.execute(@current_command, @connection_data)

  if @response_command.command_type == Hypertube::Utils::CommandType::EXCEPTION
    exception = Hypertube::Utils::Exceptions::ExceptionThrower.throw_exception(@response_command)
    raise(exception)
  end

  if @current_command.command_type == Hypertube::Utils::CommandType::CREATE_CLASS_INSTANCE
    @current_command = @response_command
    @is_executed = true
    return self
  end

  @response_command = process_update_invocation_context_commands(@response_command) unless @is_stateless

  Hypertube::Sdk::InvocationContext.new(@runtime_name, @connection_type, @connection_data, @response_command, true, @is_stateless)
end

#execute_asyncObject



94
95
96
97
98
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 94

def execute_async
  Thread.new do
    execute
  end
end

#get_enum_nameHypertube::Sdk::InvocationContext

Retrieves the name of an enum from the target runtime.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/enums/using-enum-type article on Hypertube Guides}


276
277
278
279
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 276

def get_enum_name
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::GET_ENUM_NAME, [])
  build_invocation_context(local_command)
end

#get_enum_valueHypertube::Sdk::InvocationContext

Retrieves the value of an enum from the target runtime.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/enums/using-enum-type article on Hypertube Guides}


284
285
286
287
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 284

def get_enum_value
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::GET_ENUM_VALUE, [])
  build_invocation_context(local_command)
end

#get_index(*indexes) ⇒ Hypertube::Sdk::InvocationContext

Retrieves the value at a specific indexes in an array from the target runtime.

Parameters:

  • indexes (Array)

    The indexes to pass to the get index command.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/arrays-and-collections/one-dimensional-arrays article on Hypertube Guides}


222
223
224
225
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 222

def get_index(*indexes)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::ARRAY_GET_ITEM, [*indexes])
  build_invocation_context(local_command)
end

#get_instance_field(field_name) ⇒ Hypertube::Sdk::InvocationContext

Retrieves the value of an instance field from the target runtime.

Parameters:

  • field_name (String)

    The name of the instance field to get.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/fields-and-properties/getting-and-setting-values-for-instance-fields-and-properties article on Hypertube Guides}


177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 177

def get_instance_field(field_name)
  if @is_stateless
    value = Hypertube::Sdk::Tools::GetInstanceFieldHelper.get_field_value(@current_command, field_name)
    return_command =
      if Hypertube::Utils::TypesHandler.primitive_or_none?(value)
        Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::VALUE, value)
      elsif value.is_a?(Hypertube::Utils::Command)
        value
      else
        raise ArgumentError, "Unsupported type for stateless get_instance_field: #{value.class}"
      end

    return Hypertube::Sdk::InvocationContext.new(
      @runtime_name,
      @connection_type,
      @connection_data,
      return_command,
      false,
      @is_stateless
    )
  end

  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::GET_INSTANCE_FIELD, [field_name])
  build_invocation_context(local_command)
end

#get_instance_method_as_delegate(method_name, *args) ⇒ Hypertube::Sdk::InvocationContext

Retrieves an instance method as a delegate from the target runtime.

@see Refer to this article on Hypertube Guides

Parameters:

  • method_name (String)

    The name of the instance method to retrieve as a delegate.

  • args (Array)

    The arguments to pass to the instance method.

Returns:



320
321
322
323
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 320

def get_instance_method_as_delegate(method_name, *args)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::GET_INSTANCE_METHOD_AS_DELEGATE, [method_name, *args])
  build_invocation_context(local_command)
end

#get_rankHypertube::Sdk::InvocationContext

Retrieves the rank of an array from the target runtime.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/arrays-and-collections/multidimensional-arrays article on Hypertube Guides}


248
249
250
251
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 248

def get_rank
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::ARRAY_GET_RANK, [])
  build_invocation_context(local_command)
end

#get_ref_valueHypertube::Sdk::InvocationContext

Retrieves the value of a reference from the target runtime.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/methods-arguments/passing-arguments-by-reference-with-ref-keyword article on Hypertube Guides}


292
293
294
295
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 292

def get_ref_value
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::GET_REF_VALUE, [])
  build_invocation_context(local_command)
end

#get_sizeHypertube::Sdk::InvocationContext

Retrieves the number of elements from the target runtime.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/arrays-and-collections/one-dimensional-arrays article on Hypertube Guides}


240
241
242
243
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 240

def get_size
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::ARRAY_GET_SIZE, [])
  build_invocation_context(local_command)
end

#get_static_field(field_name) ⇒ Hypertube::Sdk::InvocationContext

Retrieves the value of a static field from the target runtime.

Parameters:

  • field_name (String)

    The name of the static field to get.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/fields-and-properties/getting-and-setting-values-for-static-fields-and-properties article on Hypertube Guides}


158
159
160
161
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 158

def get_static_field(field_name)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::GET_STATIC_FIELD, [field_name])
  build_invocation_context(local_command)
end

#get_static_method_as_delegate(method_name, *args) ⇒ Hypertube::Sdk::InvocationContext

Retrieves a static method as a delegate from the target runtime.

Parameters:

  • method_name (String)

    The name of the static method to retrieve as a delegate.

  • args (Array)

    The arguments to pass to the static method.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/delegates-and-events/using-delegates article on Hypertube Guides}


310
311
312
313
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 310

def get_static_method_as_delegate(method_name, *args)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::GET_STATIC_METHOD_AS_DELEGATE, [method_name, *args])
  build_invocation_context(local_command)
end

#get_valueObject

Retrieves the value of the current command from the target runtime.

Returns:

  • (Object)

    The value of the current command.

See Also:



368
369
370
371
372
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 368

def get_value
  return @current_command.payload[0] if @current_command.command_type == Hypertube::Utils::CommandType::VALUE &&
                                          Hypertube::Utils::TypesHandler.primitive_or_none?(@current_command.payload[0])
  self
end

#invoke_generic_method(method_name, *args) ⇒ Hypertube::Sdk::InvocationContext

Invokes a generic method on the target runtime.

Parameters:

  • method_name (String)

    The name of the generic method to invoke.

  • args (Array)

    The arguments to pass to the generic method.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/generics/calling-generic-instance-method article on Hypertube Guides}


268
269
270
271
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 268

def invoke_generic_method(method_name, *args)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::INVOKE_GENERIC_METHOD, [method_name, *args])
  build_invocation_context(local_command)
end

#invoke_generic_static_method(method_name, *args) ⇒ Hypertube::Sdk::InvocationContext

Invokes a generic static method on the target runtime.

Parameters:

  • method_name (String)

    The name of the generic static method to invoke.

  • args (Array)

    The arguments to pass to the generic static method.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/generics/calling-generic-static-method article on Hypertube Guides}


258
259
260
261
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 258

def invoke_generic_static_method(method_name, *args)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::INVOKE_GENERIC_STATIC_METHOD, [method_name, *args])
  build_invocation_context(local_command)
end

#invoke_instance_method(method_name, *args) ⇒ Hypertube::Sdk::InvocationContext

Invokes an instance method on the target runtime.

Parameters:

  • method_name (String)

    The name of the instance method to invoke.

  • args (Array)

    The arguments to pass to the instance method.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/calling-methods/creating-instance-and-calling-instance-methods article on Hypertube Guides}


139
140
141
142
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 139

def invoke_instance_method(method_name, *args)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::INVOKE_INSTANCE_METHOD, [method_name, *args])
  build_invocation_context(local_command)
end

#invoke_static_method(method_name, *args) ⇒ Hypertube::Sdk::InvocationContext

Invokes a static method on the target runtime.

Parameters:

  • method_name (String)

    The name of the static method to invoke.

  • args (Array)

    The arguments to pass to the static method.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/calling-methods/invoking-static-method article on Hypertube Guides}


115
116
117
118
119
120
121
122
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 115

def invoke_static_method(method_name, *args)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::INVOKE_STATIC_METHOD, [method_name, *args])
  if @is_stateless
    local_inv_ctx = build_invocation_context(local_command)
    return local_inv_ctx.send(:pass_by_value)
  end
  build_invocation_context(local_command)
end

#iteratorObject

def finalize(command, is_executed, interpreter, connection_type, connection_data) proc do if command.command_type == Hypertube::Utils::CommandType::REFERENCE && is_executed == true destruct_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::DESTRUCT_REFERENCE, command.payload) interpreter.execute(destruct_command, connection_type, connection_data) end end end



42
43
44
45
46
47
48
49
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 42

def iterator
  if ![Hypertube::Utils::CommandType::REFERENCE, Hypertube::Utils::CommandType::ARRAY_GET_ITEM,
       Hypertube::Utils::CommandType::ARRAY_SET_ITEM].include? @current_command.command_type
    raise TypeError, "Object is not iterable for command type #{@current_command.command_type}"
  else
    Hypertube::Sdk::Internal::InvocationContextIterator.new(self)
  end
end

#process_update_invocation_context_commands(response_command) ⇒ Hypertube::Utils::Command

Processes ValueForUpdate commands in the response payload. Scans response payload for ValueForUpdate commands, updates corresponding InvocationContexts.

Parameters:

Returns:



104
105
106
107
108
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 104

def process_update_invocation_context_commands(response_command)
  # Ruby version: simply return the response_command unchanged
  # Update processing logic can be added here if needed
  response_command
end

#register_for_updateHypertube::Sdk::InvocationContext

Registers the current context for updates by wrapping it in a REGISTER_FOR_UPDATE command.

Returns:



378
379
380
381
382
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 378

def register_for_update
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::REGISTER_FOR_UPDATE, [])
  Hypertube::Sdk::InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(local_command), @is_executed,
                        @is_stateless)
end

#retrieve_arrayObject, Array

Retrieves an array from the target runtime. Retrieves an array from the target runtime.

Returns:

  • (Object)

    A new Hypertube::Sdk::InvocationContext instance that wraps the command to retrieve the array.

  • (Array)

    The retrieved array.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/arrays-and-collections/one-dimensional-arrays article on Hypertube Guides}
  • to this {https://www.hypertube.dev/guides/v2/ruby/arrays-and-collections/one-dimensional-arrays article on Hypertube Guides}


331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 331

def retrieve_array
  array_inv_ctx = self
  unless @is_stateless
    retrieve_array_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::RETRIEVE_ARRAY, [])
    local_inv_ctx = Hypertube::Sdk::InvocationContext.new(
      @runtime_name,
      @connection_type,
      @connection_data,
      build_command(retrieve_array_command)
    )
    array_inv_ctx = local_inv_ctx.execute
  end

  payload = array_inv_ctx.current_command.payload
  return [] if payload.empty?

  if payload[0].is_a?(Hypertube::Utils::Command)
    invocation_contexts = Array.new(payload.length)
    payload.each_with_index do |item, i|
      invocation_contexts[i] = Hypertube::Sdk::InvocationContext.new(
        @runtime_name,
        @connection_type,
        @connection_data,
        item,
        @is_executed,
        @is_stateless
      )
    end
    return invocation_contexts
  end

  payload
end

#set_index(indexes, value) ⇒ Hypertube::Sdk::InvocationContext

Sets the value at a specific index in an array in the target runtime.

Parameters:

  • indexes (Array)

    The indexes where new value should be set

  • value (Object)

    The new value to set at the indexes.

Returns:

See Also:



232
233
234
235
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 232

def set_index(indexes, value)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::ARRAY_SET_ITEM, [indexes, value])
  build_invocation_context(local_command)
end

#set_instance_field(field_name, value) ⇒ Hypertube::Sdk::InvocationContext

Sets the value of an instance field in the target runtime.

Parameters:

  • field_name (String)

    The name of the instance field to set.

  • value (Object)

    The new value of the instance field.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/fields-and-properties/getting-and-setting-values-for-instance-fields-and-properties article on Hypertube Guides}


208
209
210
211
212
213
214
215
216
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 208

def set_instance_field(field_name, value)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::SET_INSTANCE_FIELD, [field_name, value])
  new_command = build_command(local_command)
  if @is_stateless
    @current_command = new_command
    return self
  end
  Hypertube::Sdk::InvocationContext.new(@runtime_name, @connection_type, @connection_data, new_command, @is_executed, @is_stateless)
end

#set_static_field(field_name, value) ⇒ Hypertube::Sdk::InvocationContext

Sets the value of a static field in the target runtime.

Parameters:

  • field_name (String)

    The name of the static field to set.

  • value (Object)

    The new value of the static field.

Returns:

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/fields-and-properties/getting-and-setting-values-for-static-fields-and-properties article on Hypertube Guides}


168
169
170
171
# File 'lib/hypertube-ruby-sdk/sdk/invocation_context.rb', line 168

def set_static_field(field_name, value)
  local_command = Hypertube::Utils::Command.new(@runtime_name, Hypertube::Utils::CommandType::SET_STATIC_FIELD, [field_name, value])
  build_invocation_context(local_command)
end