Class: RuntimeContext

Inherits:
AbstractRuntimeContext show all
Defined in:
lib/hypertube-ruby-sdk/sdk/runtime_context.rb

Overview

Represents a single context which allows interaction with a selected technology. Refers to a single instance of the called runtime within a particular target OS process. This can be either the local currently running process (inMemory) or a particular remote process identified by the IP Address and PORT of the target RuntimeBridge instance. Multiple Runtime Contexts can be initialized within one process. Calling the same technology on inMemory communication channel will return the existing instance of runtime context. Calling the same technology on TCP channel but on different nodes will result in unique Runtime Contexts. Within the runtime context, any number of libraries can be loaded and any objects from the target technology can be interacted with, as they are aware of each other due to sharing the same memory space and same runtime instance.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/foundations/runtime-context article on RuntimeBridge Guides}

Constant Summary collapse

@@memory_runtime_contexts =
{}
@@network_runtime_contexts =
{}
@@ws_runtime_contexts =
{}

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(runtime_name, connection_type, connection_data) ⇒ RuntimeContext

accessor set method



30
31
32
33
34
35
36
37
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 30

def initialize(runtime_name, connection_type, connection_data)
  @runtime_name = runtime_name
  @connection_type = connection_type
  @connection_data = connection_data
  @current_command = nil
  SdkMessageHelper.send_message_to_app_insights('SdkMessage',
                                                RuntimeNameHandler.get_name(@runtime_name).capitalize + ' initialized')
end

Instance Attribute Details

#connection_dataObject (readonly)

Returns the value of attribute connection_data.



26
27
28
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 26

def connection_data
  @connection_data
end

#current_commandObject

accessor get method



25
26
27
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 25

def current_command
  @current_command
end

#runtime_nameObject (readonly)

Returns the value of attribute runtime_name.



26
27
28
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 26

def runtime_name
  @runtime_name
end

Class Method Details

.get_instance(runtime_name, connection_type, connection_data) ⇒ Object



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 39

def self.get_instance(runtime_name, connection_type, connection_data)
  case connection_type
  when ConnectionType::IN_MEMORY
    if @@memory_runtime_contexts.has_key?(runtime_name)
      runtime_ctx = @@memory_runtime_contexts[runtime_name]
      runtime_ctx.current_command = nil
      runtime_ctx
    else
      runtime_ctx = RuntimeContext.new(runtime_name, connection_type, connection_data)
      @@memory_runtime_contexts[runtime_name] = runtime_ctx
      runtime_ctx
    end
  when ConnectionType::TCP
    key = runtime_name.to_s + ':' + connection_data.to_s
    if @@network_runtime_contexts.has_key?(key)
      runtime_ctx = @@network_runtime_contexts[key]
      runtime_ctx.current_command = nil
      runtime_ctx
    else
      runtime_ctx = RuntimeContext.new(runtime_name, connection_type, connection_data)
      @@network_runtime_contexts[key] = runtime_ctx
      runtime_ctx
    end
  when ConnectionType::WEB_SOCKET
    key = runtime_name.to_s + ':' + connection_data.to_s
    if @@ws_runtime_contexts.has_key?(key)
      runtime_ctx = @@ws_runtime_contexts[key]
      runtime_ctx.current_command = nil
      runtime_ctx
    else
      runtime_ctx = RuntimeContext.new(runtime_name, connection_type, connection_data)
      @@ws_runtime_contexts[key] = runtime_ctx
      runtime_ctx
    end
  end
end

.initialize_runtime_context(config) ⇒ RuntimeContext

Initializes RuntimeContext based on the Config object and loads modules.

Parameters:

  • Instance of Config.

Returns:

  • RuntimeContext with loaded modules.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 79

def self.initialize_runtime_context(config)
  # Determine connection type from connection_data
  connection_type = if config.connection_data.nil?
                      ConnectionType::IN_MEMORY
                    elsif config.connection_data.is_a?(TcpConnectionData)
                      ConnectionType::TCP
                    elsif config.connection_data.is_a?(WsConnectionData)
                      ConnectionType::WEB_SOCKET
                    else
                      ConnectionType::IN_MEMORY
                    end

  # Create runtime context using config's runtime and connection data
  rtm_ctx = RuntimeContext.get_instance(config.runtime, connection_type, config.connection_data)

  # Load modules if connection is InMemory
  if connection_type == ConnectionType::IN_MEMORY
    modules = config.modules
    if modules && !modules.strip.empty?
      modules.split(',').each do |module_path|
        trimmed = module_path.strip
        next if trimmed.empty?

        begin
          full_path = File.realpath(File.expand_path(trimmed))
          rtm_ctx.load_library(full_path)
        rescue StandardError => e
          raise "Error resolving path for module: #{trimmed}"
        end
      end
    end
  end

  rtm_ctx
end

Instance Method Details

#as_out(*args) ⇒ InvocationContext

Creates a reference type argument that can be passed to a method with an out parameter modifier. This method is used when working with methods from the called runtime that require arguments to be passed by reference. The arguments include the value and optionally the type of the reference. The type must be retrieved from the called runtime using the getType method. After creating the reference, it can be used as an argument when invoking methods.

Parameters:

  • The value and optionally the type of the reference.

Returns:

  • InvocationContext instance.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/methods-arguments/passing-arguments-by-reference-with-out-keyword article on RuntimeBridge Guides}


202
203
204
205
206
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 202

def as_out(*args)
  local_command = Command.new(@runtime_name, CommandType::AS_OUT, [*args])
  @current_command = nil
  InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(local_command), false)
end

#as_ref(*args) ⇒ InvocationContext

Creates a reference type argument that can be passed to a method with a ref parameter modifier. This method is used when working with methods from the called runtime that require arguments to be passed by reference. The arguments include the value and optionally the type of the reference. The type must be retrieved from the called runtime using the getType method. After creating the reference, it can be used as an argument when invoking methods.

Parameters:

  • The value and optionally the type of the reference.

Returns:

  • InvocationContext instance.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/methods-arguments/passing-arguments-by-reference-with-ref-keyword article on RuntimeBridge Guides}


188
189
190
191
192
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 188

def as_ref(*args)
  local_command = Command.new(@runtime_name, CommandType::AS_REF, [*args])
  @current_command = nil
  InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(local_command), false)
end

#build_command(command) ⇒ Object



233
234
235
236
237
238
239
240
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 233

def build_command(command)
  return @current_command if command.nil? || command.payload.nil?

  command.payload.each_index do |i|
    command.payload[i] = encapsulate_payload_item(command.payload[i])
  end
  command.prepend_arg_to_payload(@current_command)
end

#cast(*args) ⇒ InvocationContext

Casts the provided value to a specific type. This method is used when invoking methods that require specific types of arguments. The arguments include the target type and the value to be cast. The target type must be retrieved from the called runtime using the getType method. After casting the value, it can be used as an argument when invoking methods. #see Refer to this article on RuntimeBridge Guides

Parameters:

  • The target type and the value to be cast.

Returns:

  • InvocationContext instance.



161
162
163
164
165
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 161

def cast(*args)
  local_command = Command.new(@runtime_name, CommandType::CAST, [*args])
  @current_command = nil
  InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(local_command), false)
end

#encapsulate_payload_item(payload_item) ⇒ Object



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 242

def encapsulate_payload_item(payload_item)
  if payload_item.is_a? Command
    payload_item.payload.each_index do |i|
      payload_item.payload[i] = encapsulate_payload_item(payload_item.payload[i])
    end
    payload_item

  elsif payload_item.is_a? InvocationContext
    payload_item.current_command

  elsif payload_item.is_a? Array
    copied_array = payload_item.map { |item| encapsulate_payload_item(item) }
    Command.new(@runtime_name, CommandType::ARRAY, copied_array)
  elsif TypesHandler.primitive_or_none?(payload_item)
    Command.new(@runtime_name, CommandType::VALUE, payload_item.nil? ? [nil] : [*payload_item])
  else
    raise TypeError, "Unsupported payload item type: #{payload_item.class} for payload item: #{payload_item}."
  end
end

#executeObject

Executes the current command. The initial state of RuntimeContext is non-materialized, wrapping either a single command or a chain of recursively nested commands. Commands become nested through each invocation of methods on RuntimeContext. Each invocation triggers the creation of a new RuntimeContext instance wrapping the current command with a new parent command. The developer can decide at any moment of the materialization for the context, taking full control of the chunks of the expression being transferred and processed on the target runtime.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/foundations/execute-method article on RuntimeBridge Guides}


121
122
123
124
125
126
127
128
129
130
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 121

def execute
  @response_command = Interpreter.execute(@current_command, @connection_type, @connection_data)
  @current_command = nil

  return unless @response_command.command_type == CommandType::EXCEPTION

  exception = ExceptionThrower.throw_exception(@response_command)
  SdkMessageHelper.send_message_to_app_insights('SdkException', exception.message)
  raise exception
end

#get_enum_item(*args) ⇒ InvocationContext

Retrieves a specific item from an enum type. This method is used when working with enums from the called runtime. The arguments include the enum type and the name of the item. The enum type must be retrieved from the called runtime using the getType method. After retrieving the item, it can be used as an argument when invoking methods.

Parameters:

  • The enum type and the name of the item.

Returns:

  • InvocationContext instance.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/enums/using-enum-type article on RuntimeBridge Guides}


174
175
176
177
178
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 174

def get_enum_item(*args)
  local_command = Command.new(@runtime_name, CommandType::GET_ENUM_ITEM, [*args])
  @current_command = nil
  InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(local_command), false)
end

#get_global_field(field_name) ⇒ InvocationContext

Retrieves the value of a global field from the called runtime. The argument includes the global field name. After retrieving the field, the result can be used for further operations.

Parameters:

  • The name of the global field to retrieve.

Returns:

  • The InvocationContext instance that wraps the command to get the global field.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/fields-and-properties/getting-values-for-global-fields article on RuntimeBridge Guides}


227
228
229
230
231
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 227

def get_global_field(field_name)
  local_command = Command.new(@runtime_name, CommandType::GET_GLOBAL_FIELD, [field_name])
  @current_command = nil
  InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(local_command), false)
end

#get_type(*args) ⇒ InvocationContext

Retrieves a reference to a specific type. The type can be a class, interface or enum. The type can be retrieved from any referenced library.

Parameters:

  • The full name of the type.

Returns:

  • InvocationContext instance.



149
150
151
152
153
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 149

def get_type(*args)
  local_command = Command.new(@runtime_name, CommandType::GET_TYPE, [*args])
  @current_command = nil
  InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(local_command), false)
end

#invoke_global_function(function_name, *args) ⇒ InvocationContext

Invokes a function from the called runtime. This method is used when working with functions from the called runtime. The arguments include the function name and the arguments to be passed to the function. After invoking the function, the result can be used for further operations.

Parameters:

  • The name of the function to invoke.

  • The arguments to be passed to the function.

Returns:

  • The InvocationContext instance that wraps the command to invoke the function.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/functions/invoking-functions article on RuntimeBridge Guides}


215
216
217
218
219
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 215

def invoke_global_function(function_name, *args)
  local_command = Command.new(@runtime_name, CommandType::INVOKE_GLOBAL_FUNCTION, [function_name, *args])
  @current_command = nil
  InvocationContext.new(@runtime_name, @connection_type, @connection_data, build_command(local_command), false)
end

#load_library(*args) ⇒ RuntimeContext

Adds a reference to a library. RuntimeBridge allows you to reference and use modules or packages written in various languages. This method allows you to use any library from all supported technologies. The necessary libraries need to be referenced. The argument is a relative or full path to the library. If the library has dependencies on other libraries, the latter needs to be added first. After referencing the library, any objects stored in this package can be used. Use static classes, create instances, call methods, use fields and properties, and much more.

Parameters:

  • The relative or full path to the library.

Returns:

  • RuntimeContext instance.

See Also:

  • to this {https://www.hypertube.dev/guides/v2/ruby/getting-started/adding-references-to-libraries article on RuntimeBridge Guides}


139
140
141
142
143
144
# File 'lib/hypertube-ruby-sdk/sdk/runtime_context.rb', line 139

def load_library(*args)
  local_command = Command.new(@runtime_name, CommandType::LOAD_LIBRARY, [*args])
  @current_command = build_command(local_command)
  execute
  self
end